Learn R Programming

tcplfit2 (version 0.1.7)

hitloginner: Hit Logic Inner (Discrete)

Description

Contains hit logic, called directly during CR fitting or later through "hitlogic".

Usage

hitloginner(conc = NULL, resp, top, cutoff, ac50 = NULL)

Value

Outputs 1 for hit, 0 for miss.

Arguments

conc

Vector of concentrations (No longer necessary).

resp

Vector of responses.

top

Model top.

cutoff

Desired cutoff.

ac50

Model AC50 (No longer necessary).

Details

The purpose of this function is to keep the actual hit rules in one location so it can be called during CR fitting, and then again after the fact for a variety of cutoffs. Curves fit with constant winning should have top = NA, generating a miss.

Examples

Run this code
hitloginner(resp = 1:8, top = 7, cutoff = 5) #hit
hitloginner(resp = 1:8, top = 7, cutoff = 7.5) #miss: top too low
hitloginner(resp = 1:8, top = 9, cutoff = 8.5) #miss: no response> cutoff
hitloginner(resp = 1:8, top = NA, cutoff = 5) #miss: no top (constant)

Run the code above in your browser using DataLab